@@ -1,6 +1,7 @@
 # Import modules
 from .MasscanScan import MasscanScan
 from .ServerScan import ServerScan
+from ._version import __version__
 import colorama as clr
 import platform
 import argparse
@@ -41,7 +42,46 @@ def load_ip_list(ip_list_location):
     return ips
 
 
+def parse_port_range(unparsed_args: str) -> list:
+    def verify_ints(port: any) -> None:
+        try:
+            int(port)
+        except TypeError:
+            print(clr.Fore.RED + f"Couldn't parse: {port}" + clr.Fore.RESET)
+            exit(1)
+
+    ports: list[int] = []
+    # Parse all separate port/ranges, separated by commas
+    separate_values: list[str] = unparsed_args.split(",")
+    # Parse all ranges
+    for value in separate_values:
+        # Check if it's a range
+        if "-" in value:
+            # Parse the range
+            port_range: list[str] = value.split("-")
+            range_start: str = port_range[0]
+            range_end: str = port_range[1]
+            for port in (range_start, range_end):
+                verify_ints(port)
+            for port in range(
+                int(range_start), int(range_end) + 1
+            ):  # Range end needs to be offset by 1 to make the range inclusive
+                ports.append(port)
+        else:
+            verify_ints(value)
+            ports.append(int(value))
+
+    return list(set(ports))
+
+
 def main():
+    if args.show_version:
+        # Show the version and exit
+        print(
+            f"yokkaichi {__version__} on {platform.python_implementation()} {platform.python_version()}"
+        )
+        exit()
+
     if platform.system() == "Windows":
         # Init colorama if on Windows
         clr.init()
@@ -60,6 +100,13 @@ def main():
         # Touch the file
         pathlib.Path(args.output_file).touch()
 
+    # Check does IP2Location db exist
+    if args.ip2location_db != "" and not pathlib.Path(args.ip2location_db).is_file():
+        print(clr.Fore.RED + "This IP2Location DB doesn't exist")
+        exit(1)
+
+    ports = parse_port_range(args.ports)
+
     # Add platforms to a list
     platforms = []
     if args.java:
@@ -88,7 +135,9 @@ def main():
         masscan_ips = masscan_ips_from_file + masscan_ips_for_countries
 
         # Start masscan
-        masscan_scanner = MasscanScan(masscan_ips, args.ports, args.masscan_args)
+        masscan_scanner = MasscanScan(
+            masscan_ips, ports, args.masscan_args, args.masscan_json_output
+        )
         masscan_results = masscan_scanner.start_scan()
     else:
         masscan_results = None
@@ -97,9 +146,9 @@ def main():
     # ips = load_file()
 
     ServerScan(
-        ip_list=None,
+        ip_list=ip_list,
         masscan_list=masscan_results,
-        ports=args.ports,
+        ports=ports,
         platforms=platforms,
         query=args.query,
         ip2location_db_file=args.ip2location_db,
@@ -151,12 +200,24 @@ if __name__ == "__main__":
         default="",
     )
     parser.add_argument(
-        "-p", "--ports", dest="ports", help="Ports to scan on", nargs="+"
+        "--masscan-output",
+        dest="masscan_json_output",
+        help="Output results to a file. To be used for debugging purposes.",
+        type=str,
+        default="",
+    )
+    parser.add_argument(
+        "-p",
+        "--ports",
+        dest="ports",
+        help="Ports to scan on. Example format: 25560-25569,42069. Uses 25565 by default",
+        type=str,
+        default="25565",
     )
     parser.add_argument(
         "--query",
         dest="query",
-        help="Query servers, required for player list but slows down the script",
+        help="Query servers, required for player list but slows down the script (Note: might be broken at the moment)",
         action="store_true",
     )
     parser.add_argument(
@@ -185,8 +246,14 @@ if __name__ == "__main__":
         "--output",
         dest="output_file",
         help="Output JSON file",
-        default=None,
-        required=True,
+        default="out.json",
+    )
+    parser.add_argument(
+        "-v",
+        "--version",
+        dest="show_version",
+        help="Show version and quit",
+        action="store_true",
     )
     parser.set_defaults(java=False, bedrock=False, query=False)
     args = parser.parse_args()
